--[[ 
Uses the dkp values from value_table.lua to display them in the ingame tooltip.
Remember to name the file precisely and regularly update it!

To update it manually, you need to export the dkp_values_raw tab in the guild
spreadsheet as a JSON.
(See for instructions:
http://blog.pamelafox.org/2013/06/exporting-google-spreadsheet-as-json.html )

Paste the result into dkpvalues.json and run convert_json_to_lua.cpython-37.pyc
If you don't trust me, the source code is included in the addon files.
--]]

-- takes information about a specific item and returns a formatted string for the tooltip
function format_tooltip(information)
    ranking = string.format("|c0099ccffRanking: %s - Value: %i DKP", information["final"] or "", 
        ranking_to_dkp(information["final"]))
    
    s = false
    a = false
    b = false
    c = false
    
    s_classes = string.format("\n|c00E0E0E0%-3s", "S:")
    for key, value in next, information do
        if value == "S" and not(key == "final") then
            s_classes = s_classes .. get_class_icon(key)
            s = true
        end
    end
    if not s then 
        s_classes = nil
    end
    
    a_classes = string.format("\n|c00E0E0E0%-3s", "A:")
    for key, value in next, information do
        if value == "A" and not(key == "final") then
            a_classes = a_classes .. get_class_icon(key)
            a = true
        end
    end
    if not a then 
        a_classes = nil
    end
    
    b_classes = string.format("\n|c00E0E0E0%-3s", "B:")
    for key, value in next, information do
        if value == "B" and not(key == "final") then
            b_classes = b_classes .. get_class_icon(key)
            b = true
        end
    end
    if not b then 
        b_classes = nil
    end
    
    c_classes = string.format("\n|c00E0E0E0%-3s", "C:")
    for key, value in next, information do
        if value == "C" and not(key == "final") then
            c_classes = c_classes .. get_class_icon(key)
            c = true
        end
    end
    if not c then 
        c_classes = nil
    end
    
    return ranking, s_classes, a_classes, b_classes, c_classes
end

GameTooltip:HookScript("OnTooltipSetItem", function(tooltip, ...)
        local itemname, _ = tooltip:GetItem()

        information = search_for_item(itemname)
        
        if information then
            ranking, s, a, b, c = format_tooltip(information)
            
            if s then
                ranking = ranking .. s
            end
            if a then
                ranking = ranking .. a
            end
            if b then
                ranking = ranking .. b
            end
            if c then
                ranking = ranking .. c
            end
            
            tooltip:AddLine(ranking)
        end
    end)
